==> 0.5.0.tar.gz: example/lib/views/switch.example.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';

class SwitchExample extends StatefulWidget {
  const SwitchExample({Key? key}) : super(key: key);

  @override
  _SwitchExampleState createState() => _SwitchExampleState();
}

class _SwitchExampleState extends State<SwitchExample> {
  bool _isDisabled = false;
  bool _optionOne = false;
  bool _optionTwo = false;
  bool _optionThree = false;
  bool _optionFour = false;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Switch Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !this._isDisabled,
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    this._isDisabled = !value;
                  });
                },
                labelPosition: SeniorSwitchLabelPosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    SeniorSwitch(
                      title: 'Receber notificações',
                      value: this._optionOne,
                      onChanged: (value) {
                        if (value == null) return;
                        setState(() {
                          this._optionOne = value;
                        });
                      },
                      disabled: this._isDisabled,
                    ),
                    SeniorSwitch(
                      title: 'Enviar com Enter',
                      value: this._optionTwo,
                      onChanged: (value) {
                        if (value == null) return;
                        setState(() {
                          this._optionTwo = value;
                        });
                      },
                      disabled: this._isDisabled,
                      labelPosition: SeniorSwitchLabelPosition.right,
                    ),
                    SeniorSwitch(
                      title: 'Atualizar automaticamente',
                      value: this._optionThree,
                      onChanged: (value) {
                        if (value == null) return;
                        setState(() {
                          this._optionThree = value;
                        });
                      },
                      disabled: this._isDisabled,
                      fullLenght: true,
                    ),
                    SeniorSwitch(
                      title: 'Salvar automaticamente',
                      value: this._optionFour,
                      onChanged: (value) {
                        if (value == null) return;
                        setState(() {
                          this._optionFour = value;
                        });
                      },
                      disabled: this._isDisabled,
                      fullLenght: true,
                      labelPosition: SeniorSwitchLabelPosition.right,
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> 0.13.1.tar.gz: example/lib/views/switch.example.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';

class SwitchExample extends StatefulWidget {
  const SwitchExample({Key? key}) : super(key: key);

  @override
  _SwitchExampleState createState() => _SwitchExampleState();
}

class _SwitchExampleState extends State<SwitchExample> {
  bool _isDisabled = false;
  bool _optionOne = false;
  bool _optionTwo = false;
  bool _optionThree = false;
  bool _optionFour = false;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Switch Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !_isDisabled,
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    _isDisabled = !value;
                  });
                },
                labelPosition: SeniorSwitchLabelPosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    SeniorSwitch(
                      title: 'Receber notificações',
                      value: _optionOne,
                      onChanged: (value) {
                        if (value == null) return;
                        setState(() {
                          _optionOne = value;
                        });
                      },
                      disabled: _isDisabled,
                    ),
                    SeniorSwitch(
                      title: 'Enviar com Enter',
                      value: _optionTwo,
                      onChanged: (value) {
                        if (value == null) return;
                        setState(() {
                          _optionTwo = value;
                        });
                      },
                      disabled: _isDisabled,
                      labelPosition: SeniorSwitchLabelPosition.right,
                    ),
                    SeniorSwitch(
                      title: 'Atualizar automaticamente',
                      value: _optionThree,
                      onChanged: (value) {
                        if (value == null) return;
                        setState(() {
                          _optionThree = value;
                        });
                      },
                      disabled: _isDisabled,
                      fullLenght: true,
                    ),
                    SeniorSwitch(
                      title: 'Salvar automaticamente',
                      value: _optionFour,
                      onChanged: (value) {
                        if (value == null) return;
                        setState(() {
                          _optionFour = value;
                        });
                      },
                      disabled: _isDisabled,
                      fullLenght: true,
                      labelPosition: SeniorSwitchLabelPosition.right,
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
